@@ -24,13 +24,13 @@ class TheSpymasterSolversClient(BaseHttpClient):
         log.debug(f"Solvers client is using backend: {wrap(self.base_url)}")
 
     def generate_hint(self, request: GenerateHintRequest) -> GenerateHintResponse:
-        data = self._post("generate-hint/", data=request.dict())
+        data = self._post("generate-hint", data=request.dict())
         return GenerateHintResponse(**data)
 
     def generate_guess(self, request: GenerateGuessRequest) -> GenerateGuessResponse:
-        data = self._post("generate-guess/", data=request.dict())
+        data = self._post("generate-guess", data=request.dict())
         return GenerateGuessResponse(**data)
 
     def load_models(self, request: LoadModelsRequest) -> LoadModelsResponse:
-        data = self._post("load-models/", data=request.dict())
+        data = self._post("load-models", data=request.dict())
         return LoadModelsResponse(**data)
